@@ -25,6 +25,12 @@ extern "C" {
 #include <stdarg.h>
 #include "magick/semaphore.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+# define magick_module  _module   /* reserved word in C++(20) */
+#else
+# define magick_module  module
+#endif
+
 typedef enum
 {
   UndefinedFormatType,
@@ -55,7 +61,7 @@ typedef struct _MagickInfo
     *description,
     *version,
     *note,
-    *module;
+    *magick_module;
 
   ImageInfo
     *image_info;
